==> syncope-2.0.10-source-release.zip: syncope-2.0.10/core/persistence-api/src/main/java/org/apache/syncope/core/persistence/api/entity/task/PullTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.api.entity.task;

import java.util.List;
import org.apache.syncope.common.lib.types.PullMode;
import org.apache.syncope.core.persistence.api.entity.AnyType;
import org.apache.syncope.core.persistence.api.entity.Realm;

public interface PullTask extends ProvisioningTask {

    PullMode getPullMode();

    void setPullMode(PullMode pullMode);

    String getReconciliationFilterBuilderClassName();

    void setReconciliationFilterBuilderClassName(String reconciliationFilterBuilderClassName);

    Realm getDestinatioRealm();

    void setDestinationRealm(Realm destinationRealm);

    boolean add(AnyTemplatePullTask template);

    AnyTemplatePullTask getTemplate(AnyType anyType);

    List<? extends AnyTemplatePullTask> getTemplates();
}

==> syncope-2.1.7-source-release.zip: syncope-2.1.7/core/persistence-api/src/main/java/org/apache/syncope/core/persistence/api/entity/task/PullTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.api.entity.task;

import java.util.List;
import java.util.Optional;
import org.apache.syncope.common.lib.types.PullMode;
import org.apache.syncope.core.persistence.api.entity.AnyType;
import org.apache.syncope.core.persistence.api.entity.Implementation;
import org.apache.syncope.core.persistence.api.entity.Realm;

public interface PullTask extends ProvisioningTask {

    PullMode getPullMode();

    void setPullMode(PullMode pullMode);

    Implementation getReconFilterBuilder();

    void setReconFilterBuilder(Implementation reconFilterBuilder);

    Realm getDestinatioRealm();

    void setDestinationRealm(Realm destinationRealm);

    boolean add(AnyTemplatePullTask template);

    Optional<? extends AnyTemplatePullTask> getTemplate(AnyType anyType);

    List<? extends AnyTemplatePullTask> getTemplates();

    void setRemediation(boolean remediation);

    boolean isRemediation();

}
